## 0.7.0 - 2023-03-31

### Added

- [#492](https://github.com/edgarrmondragon/citric/issues/492) Implement `cpd_importParticipants` in client

### Fixed

- [#774](https://github.com/edgarrmondragon/citric/issues/774) Remove direct dependency on `typing-extensions`
